@@ -1004,7 +1004,7 @@ void Thread::terminate(void)
 
 void Thread::sync(void)
 {
-#ifdef	__MACH__
+#if defined(__MACH__) || defined(__GNU__)
 	Thread::exit();
 #else
 	Thread::sleep(TIMEOUT_INF);
