@@ -23,7 +23,7 @@ public:
 	}
 	void final()
 	{
-		delete this;
+//		delete this;
 	}
 };
 
