@@ -79,10 +79,18 @@
 //#define MUTEX_UNDERGROUND_WIN32_MUTEX
 #define MUTEX_UNDERGROUND_WIN32_CRITICALSECTION
 
-// Require for compiling with critical sections.
+// Require for compiling with critical sections.  
 #define _WIN32_WINNT 0x0400
+
+#if	defined(_MSC_VER) && _MSC_VER < 1300	
 #include <windows.h>
+#endif
 #include <winsock2.h>
+#include <ws2tcpip.h>
+#if !defined(_MSC_VER) || _MSC_VER >= 1300
+#include <windows.h>
+#define CCXX_IPV6
+#endif
 #endif
 
 #ifdef WIN32
@@ -130,6 +138,8 @@ typedef unsigned long long uint64;
 # define alloca(x)      __builtin_alloca(x)
 # define THROW(x)       throw x
 # define THROWS(x)      throw(x)
+# define NEW_THROWS	throw()
+# define THROWS_EMPTY	throw()
   typedef unsigned int  uint;
 # define        snprintf            _snprintf
 # ifndef ETC_PREFIX
@@ -149,6 +159,10 @@ typedef DWORD size_t;
 #define	__EXPORT  __declspec(dllimport)
 #endif
 
+#if !defined(_MSC_VER) || _MSC_VER >= 1300
+#define	HAVE_GETADDRINFO
+#endif
+
 #define	HAVE_MEMMOVE
 #define	HAVE_SNPRINTF
 #define	snprintf	_snprintf
@@ -170,9 +184,14 @@ typedef unsigned __int16 uint16;
 typedef unsigned __int32 uint32;
 typedef unsigned __int64 uint64;
 
+#define SECS_BETWEEN_EPOCHS ((__int64)(11644473600))
+#define SECS_TO_100NS ((__int64)(10000000))
+
 #define THROW(x) throw x
 #define THROWS(x) throw(x)
 #define USING(x)
+#define	NEW_THROWS	throw()
+#define	THROWS_EMPTY	throw()
 
 #define HAVE_MODULES 1
 #undef  HAVE_PTHREAD_RWLOCK
